@@ -1,26 +1,11 @@
 use std::path::Path;
-
 use bevy::prelude::*;
 use bevy::math::vec2;
-use bevy::reflect::TypeUuid;
 use bevy::utils::HashMap;
 use bevy::asset::{LoadContext, BoxedFuture, LoadedAsset, AssetLoader, AssetPath};
 use bevy::sprite::TextureAtlas;
 use serde::Deserialize;
 
-#[derive(Debug, TypeUuid)]
-#[uuid = "b00584ad-0507-44ed-a89c-e6758f3576f6"]
-pub struct TextureAtlasManifest {
-    pub atlas: Handle<TextureAtlas>,
-    pub named_sprites: HashMap<String, usize>
-}   
-
-impl TextureAtlasManifest {
-    pub fn get_atlas_index(&self, sprite_name: &str) -> usize {
-        self.named_sprites[sprite_name]
-    }
-}
-
 #[derive(Debug, Deserialize)]
 pub struct SpriteRect {
     x: u32,
@@ -64,7 +49,6 @@ struct Manifest {
     sprites: SpriteRects,
 }
 
-
 impl From<SpriteRects> for Vec<(String, bevy::sprite::Rect)> {
     fn from(rects: SpriteRects) -> Self {
         match rects {
@@ -87,9 +71,9 @@ impl From<SpriteRects> for Vec<(String, bevy::sprite::Rect)> {
 
 
 #[derive(Default)]
-pub struct TextureAtlasManifestLoader;
+pub struct TextureAtlasLoader;
 
-impl AssetLoader for TextureAtlasManifestLoader {
+impl AssetLoader for TextureAtlasLoader {
     fn load<'a>(
         &'a self,
         bytes: &'a [u8],
@@ -112,25 +96,25 @@ impl AssetLoader for TextureAtlasManifestLoader {
             );
             
             let rects: Vec<(String, bevy::sprite::Rect)> = manifest.sprites.into();
-            let mut named_sprites = HashMap::default();
             for (name, sprite_rect) in rects.into_iter() {
                 let index = texture_atlas.add_texture(sprite_rect);
-                if name != "" {                    
-                    if let Some(_rect) = named_sprites.insert(name.clone(), index) {
+                if name != "" {      
+                    let handles = texture_atlas.texture_handles.get_or_insert(HashMap::default());
+                    let mut handle_name = manifest.path.to_owned();
+                    handle_name.push_str("#");
+                    handle_name.push_str(&name);
+                    println!("{handle_name}");
+                    let handle: Handle<Image> = load_context.get_handle(handle_name);
+                    if let Some(_rect) = handles.insert(handle.as_weak(), index) {
                         warn!("Sprite name {name} in manifest for texture atlas {} not unique", manifest.path);
                     }
+                    
                 }
             }
-            let atlas_asset = LoadedAsset::new(texture_atlas).with_dependency(image_asset_path);
-            let atlas_handle = load_context.set_labeled_asset("texture_atlas", atlas_asset);
 
-            // create asset
-            let manifest = TextureAtlasManifest {
-                atlas: atlas_handle,
-                named_sprites
-            };
-            let manifest_asset = LoadedAsset::new(manifest);
-            load_context.set_default_asset(manifest_asset);
+            // create and return the asset
+            let atlas_asset = LoadedAsset::new(texture_atlas).with_dependency(image_asset_path);
+            load_context.set_default_asset(atlas_asset);
             Ok(())
         })
     }
@@ -140,18 +124,11 @@ impl AssetLoader for TextureAtlasManifestLoader {
     }
 }
 
-#[derive(Component)]
-pub struct TextureAtlasManifestLoadedEvent {
-    pub manifest: Handle<TextureAtlasManifest>,
-    pub atlas: Handle<TextureAtlas>,
-}
+pub struct TextureAtlasLoaderPlugin;
 
-pub struct TextureAtlasManifestLoaderPlugin;
-
-impl Plugin for TextureAtlasManifestLoaderPlugin {
+impl Plugin for TextureAtlasLoaderPlugin {
     fn build(&self, app: &mut App) {
         app
-        .add_asset::<TextureAtlasManifest>()
-        .init_asset_loader::<TextureAtlasManifestLoader>();
+        .init_asset_loader::<TextureAtlasLoader>();
     }
 }
\ No newline at end of file
